# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/common.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x18\x63ogment/api/common.proto\x12\x07\x63ogment\x1a\x19google/protobuf/any.proto\"\x10\n\x0eVersionRequest\"g\n\x0bVersionInfo\x12.\n\x08versions\x18\x01 \x03(\x0b\x32\x1c.cogment.VersionInfo.Version\x1a(\n\x07Version\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x1e\n\x0bTrialConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\x1e\n\x0b\x41\x63torConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"$\n\x11\x45nvironmentConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"Q\n\x11\x45nvironmentParams\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12*\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1a.cogment.EnvironmentConfig\"Z\n\x0b\x41\x63torParams\x12\x13\n\x0b\x61\x63tor_class\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12$\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x14.cogment.ActorConfig\"\xbb\x01\n\x0bTrialParams\x12*\n\x0ctrial_config\x18\x01 \x01(\x0b\x32\x14.cogment.TrialConfig\x12/\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x1a.cogment.EnvironmentParams\x12$\n\x06\x61\x63tors\x18\x03 \x03(\x0b\x32\x14.cogment.ActorParams\x12\x11\n\tmax_steps\x18\x04 \x01(\r\x12\x16\n\x0emax_inactivity\x18\x05 \x01(\r\"4\n\x0fObservationData\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x10\n\x08snapshot\x18\x02 \x01(\x08\"Y\n\x0bObservation\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12&\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x18.cogment.ObservationData\"\x19\n\x06\x41\x63tion\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"s\n\x08\x46\x65\x65\x64\x62\x61\x63k\x12\x10\n\x08\x61\x63tor_id\x18\x01 \x01(\r\x12\x0f\n\x07tick_id\x18\x02 \x01(\x05\x12\r\n\x05value\x18\x03 \x01(\x02\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\x0c\x12\x10\n\x08\x61gent_id\x18\x07 \x01(\r\"Q\n\x06Reward\x12\r\n\x05value\x18\x01 \x01(\x02\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12$\n\tfeedbacks\x18\x03 \x03(\x0b\x32\x11.cogment.Feedback\"X\n\x07Message\x12\x11\n\tsender_id\x18\x01 \x01(\x05\x12\x13\n\x0breceiver_id\x18\x02 \x01(\x05\x12%\n\x07payload\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"7\n\x11MessageCollection\x12\"\n\x08messages\x18\x01 \x03(\x0b\x32\x10.cogment.Message\"}\n\tFinalData\x12*\n\x0cobservations\x18\x01 \x03(\x0b\x32\x14.cogment.Observation\x12 \n\x07rewards\x18\x02 \x03(\x0b\x32\x0f.cogment.Reward\x12\"\n\x08messages\x18\x03 \x03(\x0b\x32\x10.cogment.Messageb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_VERSIONREQUEST = _descriptor.Descriptor(
  name='VersionRequest',
  full_name='cogment.VersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=80,
)


_VERSIONINFO_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='cogment.VersionInfo.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='cogment.VersionInfo.Version.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='cogment.VersionInfo.Version.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=185,
)

_VERSIONINFO = _descriptor.Descriptor(
  name='VersionInfo',
  full_name='cogment.VersionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='versions', full_name='cogment.VersionInfo.versions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_VERSIONINFO_VERSION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=185,
)


_TRIALCONFIG = _descriptor.Descriptor(
  name='TrialConfig',
  full_name='cogment.TrialConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogment.TrialConfig.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=217,
)


_ACTORCONFIG = _descriptor.Descriptor(
  name='ActorConfig',
  full_name='cogment.ActorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogment.ActorConfig.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=249,
)


_ENVIRONMENTCONFIG = _descriptor.Descriptor(
  name='EnvironmentConfig',
  full_name='cogment.EnvironmentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogment.EnvironmentConfig.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=287,
)


_ENVIRONMENTPARAMS = _descriptor.Descriptor(
  name='EnvironmentParams',
  full_name='cogment.EnvironmentParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogment.EnvironmentParams.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogment.EnvironmentParams.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=370,
)


_ACTORPARAMS = _descriptor.Descriptor(
  name='ActorParams',
  full_name='cogment.ActorParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_class', full_name='cogment.ActorParams.actor_class', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='cogment.ActorParams.endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogment.ActorParams.config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=462,
)


_TRIALPARAMS = _descriptor.Descriptor(
  name='TrialParams',
  full_name='cogment.TrialParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_config', full_name='cogment.TrialParams.trial_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='environment', full_name='cogment.TrialParams.environment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actors', full_name='cogment.TrialParams.actors', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_steps', full_name='cogment.TrialParams.max_steps', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_inactivity', full_name='cogment.TrialParams.max_inactivity', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=465,
  serialized_end=652,
)


_OBSERVATIONDATA = _descriptor.Descriptor(
  name='ObservationData',
  full_name='cogment.ObservationData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogment.ObservationData.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snapshot', full_name='cogment.ObservationData.snapshot', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=706,
)


_OBSERVATION = _descriptor.Descriptor(
  name='Observation',
  full_name='cogment.Observation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogment.Observation.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogment.Observation.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='cogment.Observation.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=797,
)


_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='cogment.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='cogment.Action.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=824,
)


_FEEDBACK = _descriptor.Descriptor(
  name='Feedback',
  full_name='cogment.Feedback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='cogment.Feedback.actor_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogment.Feedback.tick_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='cogment.Feedback.value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='cogment.Feedback.confidence', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='cogment.Feedback.content', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='cogment.Feedback.agent_id', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=826,
  serialized_end=941,
)


_REWARD = _descriptor.Descriptor(
  name='Reward',
  full_name='cogment.Reward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='cogment.Reward.value', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='cogment.Reward.confidence', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feedbacks', full_name='cogment.Reward.feedbacks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=1024,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='cogment.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='cogment.Message.sender_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiver_id', full_name='cogment.Message.receiver_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='cogment.Message.payload', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1114,
)


_MESSAGECOLLECTION = _descriptor.Descriptor(
  name='MessageCollection',
  full_name='cogment.MessageCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogment.MessageCollection.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1116,
  serialized_end=1171,
)


_FINALDATA = _descriptor.Descriptor(
  name='FinalData',
  full_name='cogment.FinalData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='observations', full_name='cogment.FinalData.observations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='cogment.FinalData.rewards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogment.FinalData.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1173,
  serialized_end=1298,
)

_VERSIONINFO_VERSION.containing_type = _VERSIONINFO
_VERSIONINFO.fields_by_name['versions'].message_type = _VERSIONINFO_VERSION
_ENVIRONMENTPARAMS.fields_by_name['config'].message_type = _ENVIRONMENTCONFIG
_ACTORPARAMS.fields_by_name['config'].message_type = _ACTORCONFIG
_TRIALPARAMS.fields_by_name['trial_config'].message_type = _TRIALCONFIG
_TRIALPARAMS.fields_by_name['environment'].message_type = _ENVIRONMENTPARAMS
_TRIALPARAMS.fields_by_name['actors'].message_type = _ACTORPARAMS
_OBSERVATION.fields_by_name['data'].message_type = _OBSERVATIONDATA
_REWARD.fields_by_name['feedbacks'].message_type = _FEEDBACK
_MESSAGE.fields_by_name['payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_MESSAGECOLLECTION.fields_by_name['messages'].message_type = _MESSAGE
_FINALDATA.fields_by_name['observations'].message_type = _OBSERVATION
_FINALDATA.fields_by_name['rewards'].message_type = _REWARD
_FINALDATA.fields_by_name['messages'].message_type = _MESSAGE
DESCRIPTOR.message_types_by_name['VersionRequest'] = _VERSIONREQUEST
DESCRIPTOR.message_types_by_name['VersionInfo'] = _VERSIONINFO
DESCRIPTOR.message_types_by_name['TrialConfig'] = _TRIALCONFIG
DESCRIPTOR.message_types_by_name['ActorConfig'] = _ACTORCONFIG
DESCRIPTOR.message_types_by_name['EnvironmentConfig'] = _ENVIRONMENTCONFIG
DESCRIPTOR.message_types_by_name['EnvironmentParams'] = _ENVIRONMENTPARAMS
DESCRIPTOR.message_types_by_name['ActorParams'] = _ACTORPARAMS
DESCRIPTOR.message_types_by_name['TrialParams'] = _TRIALPARAMS
DESCRIPTOR.message_types_by_name['ObservationData'] = _OBSERVATIONDATA
DESCRIPTOR.message_types_by_name['Observation'] = _OBSERVATION
DESCRIPTOR.message_types_by_name['Action'] = _ACTION
DESCRIPTOR.message_types_by_name['Feedback'] = _FEEDBACK
DESCRIPTOR.message_types_by_name['Reward'] = _REWARD
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['MessageCollection'] = _MESSAGECOLLECTION
DESCRIPTOR.message_types_by_name['FinalData'] = _FINALDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONREQUEST,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.VersionRequest)
  })
_sym_db.RegisterMessage(VersionRequest)

VersionInfo = _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), {

  'Version' : _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
    'DESCRIPTOR' : _VERSIONINFO_VERSION,
    '__module__' : 'cogment.api.common_pb2'
    # @@protoc_insertion_point(class_scope:cogment.VersionInfo.Version)
    })
  ,
  'DESCRIPTOR' : _VERSIONINFO,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.VersionInfo)
  })
_sym_db.RegisterMessage(VersionInfo)
_sym_db.RegisterMessage(VersionInfo.Version)

TrialConfig = _reflection.GeneratedProtocolMessageType('TrialConfig', (_message.Message,), {
  'DESCRIPTOR' : _TRIALCONFIG,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.TrialConfig)
  })
_sym_db.RegisterMessage(TrialConfig)

ActorConfig = _reflection.GeneratedProtocolMessageType('ActorConfig', (_message.Message,), {
  'DESCRIPTOR' : _ACTORCONFIG,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ActorConfig)
  })
_sym_db.RegisterMessage(ActorConfig)

EnvironmentConfig = _reflection.GeneratedProtocolMessageType('EnvironmentConfig', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTCONFIG,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvironmentConfig)
  })
_sym_db.RegisterMessage(EnvironmentConfig)

EnvironmentParams = _reflection.GeneratedProtocolMessageType('EnvironmentParams', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTPARAMS,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvironmentParams)
  })
_sym_db.RegisterMessage(EnvironmentParams)

ActorParams = _reflection.GeneratedProtocolMessageType('ActorParams', (_message.Message,), {
  'DESCRIPTOR' : _ACTORPARAMS,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ActorParams)
  })
_sym_db.RegisterMessage(ActorParams)

TrialParams = _reflection.GeneratedProtocolMessageType('TrialParams', (_message.Message,), {
  'DESCRIPTOR' : _TRIALPARAMS,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.TrialParams)
  })
_sym_db.RegisterMessage(TrialParams)

ObservationData = _reflection.GeneratedProtocolMessageType('ObservationData', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONDATA,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ObservationData)
  })
_sym_db.RegisterMessage(ObservationData)

Observation = _reflection.GeneratedProtocolMessageType('Observation', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATION,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.Observation)
  })
_sym_db.RegisterMessage(Observation)

Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), {
  'DESCRIPTOR' : _ACTION,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.Action)
  })
_sym_db.RegisterMessage(Action)

Feedback = _reflection.GeneratedProtocolMessageType('Feedback', (_message.Message,), {
  'DESCRIPTOR' : _FEEDBACK,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.Feedback)
  })
_sym_db.RegisterMessage(Feedback)

Reward = _reflection.GeneratedProtocolMessageType('Reward', (_message.Message,), {
  'DESCRIPTOR' : _REWARD,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.Reward)
  })
_sym_db.RegisterMessage(Reward)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.Message)
  })
_sym_db.RegisterMessage(Message)

MessageCollection = _reflection.GeneratedProtocolMessageType('MessageCollection', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGECOLLECTION,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.MessageCollection)
  })
_sym_db.RegisterMessage(MessageCollection)

FinalData = _reflection.GeneratedProtocolMessageType('FinalData', (_message.Message,), {
  'DESCRIPTOR' : _FINALDATA,
  '__module__' : 'cogment.api.common_pb2'
  # @@protoc_insertion_point(class_scope:cogment.FinalData)
  })
_sym_db.RegisterMessage(FinalData)


# @@protoc_insertion_point(module_scope)
