# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/environment.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/environment.proto',
  package='cogment',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1d\x63ogment/api/environment.proto\x12\x07\x63ogment\x1a\x18\x63ogment/api/common.proto\"x\n\x0eObservationSet\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12\x11\n\ttimestamp\x18\x02 \x01(\x06\x12.\n\x0cobservations\x18\x03 \x03(\x0b\x32\x18.cogment.ObservationData\x12\x12\n\nactors_map\x18\x04 \x03(\x05\"\x1c\n\tActionSet\x12\x0f\n\x07\x61\x63tions\x18\x01 \x03(\x0c\"\x91\x01\n\x0f\x45nvStartRequest\x12\x10\n\x08trial_id\x18\x01 \x01(\t\x12*\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1a.cogment.EnvironmentConfig\x12*\n\x0ctrial_config\x18\x04 \x01(\x0b\x32\x14.cogment.TrialConfig\x12\x14\n\x0c\x61\x63tor_counts\x18\x03 \x03(\x05\"A\n\rEnvStartReply\x12\x30\n\x0fobservation_set\x18\x01 \x01(\x0b\x32\x17.cogment.ObservationSet\"!\n\rEnvEndRequest\x12\x10\n\x08trial_id\x18\x01 \x01(\t\"\r\n\x0b\x45nvEndReply\"i\n\x10\x45nvUpdateRequest\x12\x10\n\x08trial_id\x18\x01 \x01(\t\x12&\n\naction_set\x18\x02 \x01(\x0b\x32\x12.cogment.ActionSet\x12\x1b\n\x13reply_with_snapshot\x18\x03 \x01(\x08\"\x9f\x01\n\x0e\x45nvUpdateReply\x12\x30\n\x0fobservation_set\x18\x01 \x01(\x0b\x32\x17.cogment.ObservationSet\x12$\n\tfeedbacks\x18\x02 \x03(\x0b\x32\x11.cogment.Feedback\x12\x11\n\tend_trial\x18\x03 \x01(\x08\x12\"\n\x08messages\x18\x04 \x03(\x0b\x32\x10.cogment.Message\"]\n\x13\x45nvOnMessageRequest\x12\x10\n\x08trial_id\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tor_id\x18\x02 \x01(\x05\x12\"\n\x08messages\x18\x03 \x03(\x0b\x32\x10.cogment.Message\"\x13\n\x11\x45nvOnMessageReply2\xc6\x02\n\x0b\x45nvironment\x12;\n\x05Start\x12\x18.cogment.EnvStartRequest\x1a\x16.cogment.EnvStartReply\"\x00\x12\x35\n\x03\x45nd\x12\x16.cogment.EnvEndRequest\x1a\x14.cogment.EnvEndReply\"\x00\x12>\n\x06Update\x12\x19.cogment.EnvUpdateRequest\x1a\x17.cogment.EnvUpdateReply\"\x00\x12:\n\x07Version\x12\x17.cogment.VersionRequest\x1a\x14.cogment.VersionInfo\"\x00\x12G\n\tOnMessage\x12\x1c.cogment.EnvOnMessageRequest\x1a\x1a.cogment.EnvOnMessageReply\"\x00\x62\x06proto3')
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,])




_OBSERVATIONSET = _descriptor.Descriptor(
  name='ObservationSet',
  full_name='cogment.ObservationSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogment.ObservationSet.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogment.ObservationSet.timestamp', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='observations', full_name='cogment.ObservationSet.observations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actors_map', full_name='cogment.ObservationSet.actors_map', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=188,
)


_ACTIONSET = _descriptor.Descriptor(
  name='ActionSet',
  full_name='cogment.ActionSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='cogment.ActionSet.actions', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=218,
)


_ENVSTARTREQUEST = _descriptor.Descriptor(
  name='EnvStartRequest',
  full_name='cogment.EnvStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogment.EnvStartRequest.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='cogment.EnvStartRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trial_config', full_name='cogment.EnvStartRequest.trial_config', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actor_counts', full_name='cogment.EnvStartRequest.actor_counts', index=3,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=366,
)


_ENVSTARTREPLY = _descriptor.Descriptor(
  name='EnvStartReply',
  full_name='cogment.EnvStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='observation_set', full_name='cogment.EnvStartReply.observation_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=433,
)


_ENVENDREQUEST = _descriptor.Descriptor(
  name='EnvEndRequest',
  full_name='cogment.EnvEndRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogment.EnvEndRequest.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=435,
  serialized_end=468,
)


_ENVENDREPLY = _descriptor.Descriptor(
  name='EnvEndReply',
  full_name='cogment.EnvEndReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=483,
)


_ENVUPDATEREQUEST = _descriptor.Descriptor(
  name='EnvUpdateRequest',
  full_name='cogment.EnvUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogment.EnvUpdateRequest.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_set', full_name='cogment.EnvUpdateRequest.action_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reply_with_snapshot', full_name='cogment.EnvUpdateRequest.reply_with_snapshot', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=590,
)


_ENVUPDATEREPLY = _descriptor.Descriptor(
  name='EnvUpdateReply',
  full_name='cogment.EnvUpdateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='observation_set', full_name='cogment.EnvUpdateReply.observation_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feedbacks', full_name='cogment.EnvUpdateReply.feedbacks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_trial', full_name='cogment.EnvUpdateReply.end_trial', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogment.EnvUpdateReply.messages', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=752,
)


_ENVONMESSAGEREQUEST = _descriptor.Descriptor(
  name='EnvOnMessageRequest',
  full_name='cogment.EnvOnMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogment.EnvOnMessageRequest.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='cogment.EnvOnMessageRequest.actor_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messages', full_name='cogment.EnvOnMessageRequest.messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=847,
)


_ENVONMESSAGEREPLY = _descriptor.Descriptor(
  name='EnvOnMessageReply',
  full_name='cogment.EnvOnMessageReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=868,
)

_OBSERVATIONSET.fields_by_name['observations'].message_type = cogment_dot_api_dot_common__pb2._OBSERVATIONDATA
_ENVSTARTREQUEST.fields_by_name['config'].message_type = cogment_dot_api_dot_common__pb2._ENVIRONMENTCONFIG
_ENVSTARTREQUEST.fields_by_name['trial_config'].message_type = cogment_dot_api_dot_common__pb2._TRIALCONFIG
_ENVSTARTREPLY.fields_by_name['observation_set'].message_type = _OBSERVATIONSET
_ENVUPDATEREQUEST.fields_by_name['action_set'].message_type = _ACTIONSET
_ENVUPDATEREPLY.fields_by_name['observation_set'].message_type = _OBSERVATIONSET
_ENVUPDATEREPLY.fields_by_name['feedbacks'].message_type = cogment_dot_api_dot_common__pb2._FEEDBACK
_ENVUPDATEREPLY.fields_by_name['messages'].message_type = cogment_dot_api_dot_common__pb2._MESSAGE
_ENVONMESSAGEREQUEST.fields_by_name['messages'].message_type = cogment_dot_api_dot_common__pb2._MESSAGE
DESCRIPTOR.message_types_by_name['ObservationSet'] = _OBSERVATIONSET
DESCRIPTOR.message_types_by_name['ActionSet'] = _ACTIONSET
DESCRIPTOR.message_types_by_name['EnvStartRequest'] = _ENVSTARTREQUEST
DESCRIPTOR.message_types_by_name['EnvStartReply'] = _ENVSTARTREPLY
DESCRIPTOR.message_types_by_name['EnvEndRequest'] = _ENVENDREQUEST
DESCRIPTOR.message_types_by_name['EnvEndReply'] = _ENVENDREPLY
DESCRIPTOR.message_types_by_name['EnvUpdateRequest'] = _ENVUPDATEREQUEST
DESCRIPTOR.message_types_by_name['EnvUpdateReply'] = _ENVUPDATEREPLY
DESCRIPTOR.message_types_by_name['EnvOnMessageRequest'] = _ENVONMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['EnvOnMessageReply'] = _ENVONMESSAGEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObservationSet = _reflection.GeneratedProtocolMessageType('ObservationSet', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONSET,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ObservationSet)
  })
_sym_db.RegisterMessage(ObservationSet)

ActionSet = _reflection.GeneratedProtocolMessageType('ActionSet', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONSET,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.ActionSet)
  })
_sym_db.RegisterMessage(ActionSet)

EnvStartRequest = _reflection.GeneratedProtocolMessageType('EnvStartRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENVSTARTREQUEST,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvStartRequest)
  })
_sym_db.RegisterMessage(EnvStartRequest)

EnvStartReply = _reflection.GeneratedProtocolMessageType('EnvStartReply', (_message.Message,), {
  'DESCRIPTOR' : _ENVSTARTREPLY,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvStartReply)
  })
_sym_db.RegisterMessage(EnvStartReply)

EnvEndRequest = _reflection.GeneratedProtocolMessageType('EnvEndRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENVENDREQUEST,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvEndRequest)
  })
_sym_db.RegisterMessage(EnvEndRequest)

EnvEndReply = _reflection.GeneratedProtocolMessageType('EnvEndReply', (_message.Message,), {
  'DESCRIPTOR' : _ENVENDREPLY,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvEndReply)
  })
_sym_db.RegisterMessage(EnvEndReply)

EnvUpdateRequest = _reflection.GeneratedProtocolMessageType('EnvUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENVUPDATEREQUEST,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvUpdateRequest)
  })
_sym_db.RegisterMessage(EnvUpdateRequest)

EnvUpdateReply = _reflection.GeneratedProtocolMessageType('EnvUpdateReply', (_message.Message,), {
  'DESCRIPTOR' : _ENVUPDATEREPLY,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvUpdateReply)
  })
_sym_db.RegisterMessage(EnvUpdateReply)

EnvOnMessageRequest = _reflection.GeneratedProtocolMessageType('EnvOnMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENVONMESSAGEREQUEST,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvOnMessageRequest)
  })
_sym_db.RegisterMessage(EnvOnMessageRequest)

EnvOnMessageReply = _reflection.GeneratedProtocolMessageType('EnvOnMessageReply', (_message.Message,), {
  'DESCRIPTOR' : _ENVONMESSAGEREPLY,
  '__module__' : 'cogment.api.environment_pb2'
  # @@protoc_insertion_point(class_scope:cogment.EnvOnMessageReply)
  })
_sym_db.RegisterMessage(EnvOnMessageReply)



_ENVIRONMENT = _descriptor.ServiceDescriptor(
  name='Environment',
  full_name='cogment.Environment',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=871,
  serialized_end=1197,
  methods=[
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='cogment.Environment.Start',
    index=0,
    containing_service=None,
    input_type=_ENVSTARTREQUEST,
    output_type=_ENVSTARTREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='End',
    full_name='cogment.Environment.End',
    index=1,
    containing_service=None,
    input_type=_ENVENDREQUEST,
    output_type=_ENVENDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='cogment.Environment.Update',
    index=2,
    containing_service=None,
    input_type=_ENVUPDATEREQUEST,
    output_type=_ENVUPDATEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogment.Environment.Version',
    index=3,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OnMessage',
    full_name='cogment.Environment.OnMessage',
    index=4,
    containing_service=None,
    input_type=_ENVONMESSAGEREQUEST,
    output_type=_ENVONMESSAGEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENVIRONMENT)

DESCRIPTOR.services_by_name['Environment'] = _ENVIRONMENT

# @@protoc_insertion_point(module_scope)
